@@ -2,6 +2,7 @@
 This isn't actually a unit test lol.
 """
 import asyncio
+import pprint
 
 from blaseball_mike.events import stream_events
 from blaseball_mike.models import Game
@@ -19,9 +20,14 @@ async def test_stream():
 
 
 async def test_stream_data():
-    async for event in stream_events():
+    async for event in stream_events(url='http://localhost:8080/streamData'):
         payload = StreamData(event)
         print(payload)
+        schedule = {
+            id: g for id, g in payload.games.schedule.games.items()
+        }
+        print(schedule)
+        print(payload.leagues.teams)
 
 
 def test():
